| LCxt | R Documentation |
Predict the Lethal Concentration at any specified time point for
a SurvFit object.
The function LCx, x\
the dose required to kill x\
after a specified test duration (time_LCx) (default is the maximum
time point of the experiment).
Mathematical definition of x\
denoted LC(x,t), is:
S(LC(x,t), t) = S(0, t)*(1- x/100),
where S(LC(x,t), t) is the survival probability at concentration
LC(x,t) at time t, and S(0,t) is the survival probability at
no concentration (i.e. concentration is 0) at time t which
reflect the background mortality h_b:
S(0, t) = exp(-hb* t).
In the function LCx, we use the median of S(0,t) to rescale the
x\
lcxt(fit, x, t, ...)
## S3 method for class 'SurvFit'
lcxt(
fit,
x = 0.5,
t = NULL,
exposure_range = NULL,
interpolate_length = 50,
...
)
fit |
An object used to select a method |
x |
rate of individuals dying (e.g., |
t |
A number giving the time at which |
... |
Further arguments to be passed to generic methods |
exposure_range |
A vector of length 2 with minimal and maximal value of the range of concentration. If NULL, the range is define between 0 and the highest tested concentration of the experiment. |
interpolate_length |
of time point in the range of concentration between 0 and the maximal concentration. 100 by default. description. |
The function returns an object of class LCx, which is a list
with the following information:
X_propSurvival probability of individuals surviving considering the median
of the background mortality (i.e. S(0, t)*(1- x/100)).
X_prop_providedSurvival probability of individuals surviving as
provided in arguments (i.e. (100-X)/100).
time_LCxA number giving the time at which LC_{x} has to be
estimated as provided in arguments or if NULL, the latest time point of the
experiment is used.
df_LCxA data.frame with quantiles (median, 2.5\
of LC_{X} at time time_LCx for X\
df_doseA data.frame with four columns: concentration, and median q50 and 95\
(qinf95 and qsup95) of the survival probability at time time_LCx.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.