| LPxt | R Documentation |
Predict the Lethal Profile factor leading to $x$ % of reduction in survival at a specific time $t$.
Generic method for LPxt, a function denoted LP(x,t) for
x\
lpxt(fit, x, ...)
## S3 method for class 'SurvFit'
lpxt(
fit,
x = 0.5,
t = NULL,
display.exposure = NULL,
interpolate_length = NULL,
max.steps = 100,
accuracy = 0.01,
...
)
## S3 method for class 'LPxt'
update(object, accuracy = 0.01, max.steps = 100, ...)
fit |
An object used to select a method |
x |
rate of individuals dying (e.g., |
... |
Further arguments to be passed to generic methods |
t |
A number giving the time at which |
display.exposure |
A vector of the exposure porfile |
interpolate_length |
of time point in the range of concentration between 0 and the maximal concentration. 100 by default. description. |
max.steps |
max steps to find the LPxt |
accuracy |
accuracy of the LPxt algorithm (stop when reaching the accuracy). |
object |
An object of class |
returns an object of class LPxt
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.