Survival function for "IT" model with external concentration changing with time
SurvIT_cst(Cw, time, kd, hb, alpha, beta, interpolate_length = NULL)A data.frame with exposure columns time and conc and
the resulting probabilisty of survival in Psurv_XX column where
XX refer to an MCMC iteration
A vector of external concentration
A vector of time
a vector of parameter
a vector of parameter
a vector of parameter
a vector of parameter
can be used to provide a sequence from 0 to maximum of the time of exposure in original dataset (used for fitting).