create the table of posterior estimated parameters for the survival analyses
survFit_TKTD_params(mcmc, model_type, hb_value = TRUE)a data.frame with 3 columns (values, CIinf, CIsup) and
3-4rows (the estimated parameters)
list of estimated parameters for the model with each item representing a chain
model type SD or IT
TRUE or FALSE, conservning the use of hb parameter in the model.